# Mezzala
> Models for estimating football (soccer) team-strength


## Install

`pip install your_project_name`

## How to use

Fill me in please! Don't forget code examples:

```python
1+1
```




    2


